Biochemistry
============

Michaelis–Menten Kinetics
-------------------------

``colour.biochemistry``

.. currentmodule:: colour.biochemistry

.. autosummary::
    :toctree: generated/

    REACTION_RATE_MICHAELISMENTEN_METHODS
    reaction_rate_MichaelisMenten
    SUBSTRATE_CONCENTRATION_MICHAELISMENTEN_METHODS
    substrate_concentration_MichaelisMenten
    reaction_rate_MichaelisMenten_Michaelis1913
    substrate_concentration_MichaelisMenten_Michaelis1913
    reaction_rate_MichaelisMenten_Abebe2017
    substrate_concentration_MichaelisMenten_Abebe2017
